# django-copy-tables

This utility allows for copying tables from a production/staging server to a development copy. This allows developing against full datasets.

## Installation
It's on pypi, so install via pip (or add to your requirements.txt)
```
pip3 install django-copy-tables
```



### Usage


